@@ -2,11 +2,11 @@ package Glib::Install::Files;
 
 $self = {
           'libs' => '-L/usr/local/lib -lgobject-2.0 -lglib-2.0 -lintl ',
-          'inc' => ' -I. -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include -I/usr/local/include  -DGPERL_DISABLE_THREADSAFE ',
           'typemaps' => [
                           'typemap'
                         ],
-          'deps' => []
+          'deps' => [],
+          'inc' => ' -I. -I/usr/local/include -I/usr/local/include/glib-2.0 -I/usr/local/lib/glib-2.0/include  -DGPERL_DISABLE_THREADSAFE '
         };
 
 
